summaryrefslogtreecommitdiffstats
path: root/src/interface.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/interface.h')
-rw-r--r--src/interface.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/interface.h b/src/interface.h
index 931a2c1b3..aa0281db3 100644
--- a/src/interface.h
+++ b/src/interface.h
@@ -185,10 +185,10 @@ class ContextMenu : public Gtk::Menu
/**
* callback, is executed on clicking the anchor "Ungroup" menu entry
*/
void ActivateUngroup(void);
-
+ void ActivateGroup(void);
void AnchorLinkProperties(void);
/**
@@ -185,10 +185,10 @@ class ContextMenu : public Gtk::Menu
/**
- * callback, is executed on clicking the anchor "Ungroup" menu entry
+ * callback, is executed on clicking the anchor "Group" and "Ungroup" menu entry
*/
void ActivateUngroup(void);